@@ -248,7 +248,7 @@ class BluewhaleReader(FileFormat, DataTableMixin):
     SUPPORT_COMPRESSED = True
     SUPPORT_SPARSE_DATA = True
 
-    def read(self, name):
+    def read(self, name, pre):
         try:
             con = sqlite3.connect(self.filename)
             c = con.cursor()
@@ -265,10 +265,16 @@ class BluewhaleReader(FileFormat, DataTableMixin):
                 strtext.append(temp)
             strtext_json = json.dumps(strtext)
             df = pd.read_json(strtext_json, orient='records')
-            desc_sql = '''SELECT Intro, Alias from bwds_meta WHERE Table_name='%s' and Type='TAB';''' % (name)
-            desc = c.execute(desc_sql).fetchone()
-            attributes = {'Name': desc[1], 'Description': desc[0]}
-            table = self.pandas_to_table(df, attributes)
+            if pre:
+                desc_sql = '''SELECT Intro, Alias from bwds_meta WHERE Table_name='%s' and Type='TAB';''' % (name)
+                desc = c.execute(desc_sql).fetchone()
+                attributes = {'Name': desc[1], 'Description': desc[0]}
+                table_field = '''SELECT Name, Alias from bwds_meta WHERE Table_name='%s' and Type='COL';''' % (name)
+                field = c.execute(table_field).fetchall()
+                df.rename(columns={name[0]: name[1] for name in field}, inplace=True)
+                table = self.pandas_to_table(df, attr=attributes)
+            else:
+                table = self.pandas_to_table(df)
 
             if not isinstance(table, Table):
                 raise TypeError("file does not contain a data table")
@@ -277,7 +283,7 @@ class BluewhaleReader(FileFormat, DataTableMixin):
         except Exception:
             raise KeyError('参数不正确')
 
-    def pandas_to_table(self, df, attr):
+    def pandas_to_table(self, df, attr=None):
         # type: (pd.DataFrame) -> Orange.data.Table
         """
         Convert a pandas.DataFrame to a Orange.data.Table instance.
@@ -396,7 +402,7 @@ class _BaseExcelReader(FileFormat, DataTableMixin):
             cells = self.get_cells()
             table = self.data_table(cells)
             table.name = path.splitext(path.split(self.filename)[-1])[0]
-            if self.sheet:
+            if self.sheet and len(self.sheets) > 1:
                 table.name = '-'.join((table.name, self.sheet))
         except Exception:
             raise IOError("Couldn't load spreadsheet from " + self.filename)
@@ -409,6 +415,10 @@ class ExcelReader(_BaseExcelReader):
     DESCRIPTION = 'Microsoft Excel spreadsheet'
     ERRORS = ("#VALUE!", "#DIV/0!", "#REF!", "#NUM!", "#NULL!", "#NAME?")
 
+    def __init__(self, filename):
+        super().__init__(filename)
+        self.sheet = self.workbook.active.title
+
     @property
     def workbook(self) -> openpyxl.Workbook:
         if not self._workbook:
@@ -472,6 +482,10 @@ class XlsReader(_BaseExcelReader):
     EXTENSIONS = ('.xls',)
     DESCRIPTION = 'Microsoft Excel 97-2004 spreadsheet'
 
+    def __init__(self, filename):
+        super().__init__(filename)
+        self.sheet = self.workbook.sheet_by_index(0).name
+
     @property
     def workbook(self) -> xlrd.Book:
         if not self._workbook:
