@@ -711,7 +711,7 @@ class OWCSVFileImport(widget.OWWidget):
         ###########
         # Info text
         ###########
-        box = gui.widgetBox(self.controlArea, i18n.t("common.software.info"), addSpace=False)
+        box = gui.widgetBox(self.controlArea, i18n.t("common.software.info"))
         self.summary_text = QTextBrowser(
             verticalScrollBarPolicy=Qt.ScrollBarAsNeeded,
             readOnly=True,
