@@ -14,6 +14,7 @@ import random
 import logging
 import ast
 import types
+import unicodedata
 
 from traceback import format_exception_only
 from collections import namedtuple, OrderedDict
@@ -500,11 +501,7 @@ class OWFeatureConstructor(OWWidget):
 
         box.layout().addLayout(layout, 1)
 
-        box = gui.hBox(self.controlArea)
-        gui.rubber(box)
-        commit = gui.button(box, self, __("btn_send"), callback=self.apply,
-                            default=True)
-        commit.setMinimumWidth(180)
+        gui.button(self.buttonsArea, self, __("btn_send"), callback=self.apply, default=True)
 
     def setCurrentIndex(self, index):
         index = min(index, len(self.featuremodel) - 1)
@@ -921,7 +918,8 @@ def bind_variable(descriptor, env, data):
 
     exp_ast = ast.parse(descriptor.expression, mode="eval")
     freev = unique(freevars(exp_ast, []))
-    variables = {sanitized_name(v.name): v for v in env}
+    variables = {unicodedata.normalize("NFKC", sanitized_name(v.name)): v
+                 for v in env}
     source_vars = [(name, variables[name]) for name in freev
                    if name in variables]
 
