@@ -23,6 +23,7 @@ from AnyQt.QtWidgets import QStyledItemDelegate, QGraphicsScene, QTableView, \
 import Orange.statistics.util as ut
 from Orange.data import Table, StringVariable, DiscreteVariable, \
     ContinuousVariable, TimeVariable, Domain, Variable
+from Orange.util import utc_from_timestamp
 from Orange.widgets import widget, gui
 from Orange.widgets.data.utils.histogram import Histogram
 from Orange.widgets.settings import Setting, ContextSetting, \
@@ -33,6 +34,7 @@ from Orange.widgets.utils.widgetpreview import WidgetPreview
 from Orange.widgets.utils.state_summary import format_summary_details
 from Orange.i18n_config import *
 
+
 def _categorical_entropy(x):
     """Compute the entropy of a dense/sparse matrix, column-wise. Assuming
     categorical values."""
@@ -69,8 +71,8 @@ def format_time_diff(start, end, round_up_after=2):
     str
 
     """
-    start = datetime.datetime.fromtimestamp(start)
-    end = datetime.datetime.fromtimestamp(end)
+    start = utc_from_timestamp(start)
+    end = utc_from_timestamp(end)
     diff = abs(end - start)  # type: datetime.timedelta
 
     # Get the different resolutions
@@ -99,10 +101,10 @@ def format_time_diff(start, end, round_up_after=2):
         return '%d seconds' % seconds
 
 
-
 def __(key):
     return i18n.t("widget.data.data.owfeaturestatistics." + key)
 
+
 class FeatureStatisticsTableModel(AbstractSortTableModel):
     CLASS_VAR, META, ATTRIBUTE = range(3)
     COLOR_FOR_ROLE = {
@@ -114,18 +116,20 @@ class FeatureStatisticsTableModel(AbstractSortTableModel):
     HIDDEN_VAR_TYPES = (StringVariable,)
 
     class Columns(IntEnum):
-        ICON, NAME, DISTRIBUTION, CENTER, DISPERSION, MIN, MAX, MISSING = range(8)
+        ICON, NAME, DISTRIBUTION, CENTER, MEDIAN, DISPERSION, MIN, MAX, \
+        MISSING = range(9)
 
         @property
         def name(self):
             return {self.ICON: '',
-                    self.NAME: __('label.name'),
+                    self.NAME: __("label.name"),
                     self.DISTRIBUTION: i18n.t("common.general.distribution"),
-                    self.CENTER: __('label.center'),
-                    self.DISPERSION: i18n.t("common.general.distribution"),
-                    self.MIN: __('label.min'),
-                    self.MAX: __('label.max'),
-                    self.MISSING: __('label.missing'),
+                    self.CENTER: __("label.mean"),
+                    self.MEDIAN: __("label.median"),
+                    self.DISPERSION: __("label.dispersion"),
+                    self.MIN: __("label.min"),
+                    self.MAX: __("label.max"),
+                    self.MISSING: __("label.missing"),
                     }[self.value]
 
         @property
@@ -161,7 +165,7 @@ class FeatureStatisticsTableModel(AbstractSortTableModel):
 
         no_data = np.array([])
         self._variable_types = self._variable_names = no_data
-        self._min = self._max = self._center = no_data
+        self._min = self._max = self._center = self._median = no_data
         self._dispersion = no_data
         self._missing = no_data
         # Clear model initially to set default values
@@ -279,11 +283,18 @@ class FeatureStatisticsTableModel(AbstractSortTableModel):
 
         self._center = self.__compute_stat(
             matrices,
-            discrete_f=lambda x: __mode(x, axis=0),
+            discrete_f=None,
             continuous_f=lambda x: ut.nanmean(x, axis=0),
             time_f=lambda x: ut.nanmean(x, axis=0),
         )
 
+        self._median = self.__compute_stat(
+            matrices,
+            discrete_f=lambda x: __mode(x, axis=0),
+            continuous_f=lambda x: ut.nanmedian(x, axis=0),
+            time_f=lambda x: ut.nanmedian(x, axis=0),
+        )
+
     def get_statistics_matrix(self, variables=None, return_labels=False):
         """Get the numeric computed statistics in a single matrix. Optionally,
         we can specify for which variables we want the stats. Also, we can get
@@ -315,14 +326,16 @@ class FeatureStatisticsTableModel(AbstractSortTableModel):
             indices = ...
 
         matrix = np.vstack((
-            self._center[indices], self._dispersion[indices],
+            self._center[indices], self._median[indices],
+            self._dispersion[indices],
             self._min[indices], self._max[indices], self._missing[indices],
         )).T
 
         # Return string labels for the returned matrix columns e.g. 'Mean',
         # 'Dispersion' if requested
         if return_labels:
-            labels = [self.Columns.CENTER.name, self.Columns.DISPERSION.name,
+            labels = [self.Columns.CENTER.name, self.Columns.MEDIAN.name,
+                      self.Columns.DISPERSION.name,
                       self.Columns.MIN.name, self.Columns.MAX.name,
                       self.Columns.MISSING.name]
             return labels, matrix
@@ -379,14 +392,17 @@ class FeatureStatisticsTableModel(AbstractSortTableModel):
         to group those variable types together.
         """
         # Prepare indices for variable types so we can group them together
-        order = [DiscreteVariable, ContinuousVariable, TimeVariable, StringVariable]
+        order = [ContinuousVariable, TimeVariable,
+                 DiscreteVariable, StringVariable]
         mapping = {var: idx for idx, var in enumerate(order)}
         vmapping = np.vectorize(mapping.__getitem__)
         var_types_indices = vmapping(self._variable_types)
 
         # Store the variable name sorted indices so we can pass a default
         # order when sorting by multiple keys
-        var_name_indices = np.argsort(self._variable_names)
+        # Double argsort is "inverse" argsort:
+        # data will be *sorted* by these indices
+        var_name_indices = np.argsort(np.argsort(self._variable_names))
 
         # Prepare vartype indices so ready when needed
         disc_idx, _, time_idx, str_idx = self._attr_indices(self.variables)
@@ -410,6 +426,13 @@ class FeatureStatisticsTableModel(AbstractSortTableModel):
             vals[disc_idx] = var_name_indices[disc_idx]
             vals[str_idx] = var_name_indices[str_idx]
             return np.vstack((var_types_indices, np.zeros_like(vals), vals)).T
+        # Sort by: (type, median)
+        elif column == self.Columns.MEDIAN:
+            # Sorting discrete or string values by median makes no sense
+            vals = np.array(self._median)
+            vals[disc_idx] = var_name_indices[disc_idx]
+            vals[str_idx] = var_name_indices[str_idx]
+            return np.vstack((var_types_indices, np.zeros_like(vals), vals)).T
         # Sort by: (type, dispersion)
         elif column == self.Columns.DISPERSION:
             # Sort time variables by their dispersion, which is not stored in
@@ -447,12 +470,21 @@ class FeatureStatisticsTableModel(AbstractSortTableModel):
 
     def _argsortData(self, data, order):
         if data.ndim == 1:
-            indices = np.argsort(data, kind='mergesort')
-            if order == Qt.DescendingOrder:
-                indices = indices[::-1]
-            # Always sort NaNs last
             if np.issubdtype(data.dtype, np.number):
-                indices = np.roll(indices, -np.isnan(data).sum())
+                if order == Qt.DescendingOrder:
+                    data = -data
+                indices = np.argsort(data, kind='stable')
+                # Always sort NaNs last
+                if np.issubdtype(data.dtype, np.number):
+                    indices = np.roll(indices, -np.isnan(data).sum())
+            else:
+                # When not sorting by numbers, we can't do data = -data, but
+                # use indices = indices[::-1] instead. This is not stable, but
+                # doesn't matter because we use this only for variable names
+                # which are guaranteed to be unique
+                indices = np.argsort(data)
+                if order == Qt.DescendingOrder:
+                    indices = indices[::-1]
         else:
             assert np.issubdtype(data.dtype, np.number), \
                 'We do not deal with non numeric values in sorting by ' \
@@ -542,6 +574,8 @@ class FeatureStatisticsTableModel(AbstractSortTableModel):
                     return self.__distributions_cache[row]
             elif column == self.Columns.CENTER:
                 return render_value(self._center[row])
+            elif column == self.Columns.MEDIAN:
+                return render_value(self._median[row])
             elif column == self.Columns.DISPERSION:
                 if isinstance(attribute, TimeVariable):
                     return format_time_diff(self._min[row], self._max[row])
@@ -714,8 +748,7 @@ class OWFeatureStatistics(widget.OWWidget):
         reduced_data = Output("Reduced Data", Table, default=True, label=i18n.t("widget.data.data.common.reduced_data"))
         statistics = Output("Statistics", Table, label=i18n.t("common.general.statistics"))
 
-    want_control_area = False
-    buttons_area_orientation = Qt.Vertical
+    want_main_area = False
 
     settingsHandler = DomainContextHandler()
     settings_version = 2
@@ -724,7 +757,7 @@ class OWFeatureStatistics(widget.OWWidget):
     color_var = ContextSetting(None)  # type: Optional[Variable]
     # filter_string = ContextSetting('')
 
-    sorting = Setting((0, Qt.DescendingOrder))
+    sorting = Setting((0, Qt.AscendingOrder))
     selected_vars = ContextSetting([], schema_only=True)
 
     def __init__(self):
@@ -742,34 +775,30 @@ class OWFeatureStatistics(widget.OWWidget):
         # shortcut = QShortcut(QKeySequence('Ctrl+f'), self, self.filter_text.setFocus)
         # shortcut.setWhatsThis('Filter variables by name')
 
-        box = gui.hBox(None, box=False)
-        box.setContentsMargins(0, 0, 0, 0)
-
-        self.color_var_model = DomainModel(
-            valid_types=(ContinuousVariable, DiscreteVariable),
-            placeholder=i18n.t('common.software.none'),
-        )
-        self.cb_color_var = gui.comboBox(
-            box, master=self, value='color_var', model=self.color_var_model,
-            label=i18n.t("common.software.color"), orientation=Qt.Horizontal, contentsLength=13,
-            searchable=True
-        )
-        self.cb_color_var.activated.connect(self.__color_var_changed)
-
-        gui.rubber(box)
-        gui.auto_send(box, self, "auto_commit", box=None)
-        self.mainArea.layout().addWidget(box)
-
-        self.info.set_input_summary(self.info.NoInput)
-        self.info.set_output_summary(self.info.NoOutput)
-
         # Main area
         self.model = FeatureStatisticsTableModel(parent=self)
         self.table_view = FeatureStatisticsTableView(self.model, parent=self)
         self.table_view.selectionModel().selectionChanged.connect(self.on_select)
         self.table_view.horizontalHeader().sectionClicked.connect(self.on_header_click)
 
-        self.mainArea.layout().addWidget(self.table_view)
+        self.controlArea.layout().addWidget(self.table_view)
+
+        self.color_var_model = DomainModel(
+            valid_types=(ContinuousVariable, DiscreteVariable),
+            placeholder=i18n.t('common.software.none'),
+        )
+        self.cb_color_var = gui.comboBox(
+            self.buttonsArea, master=self, value='color_var', model=self.color_var_model,
+            label=i18n.t("common.software.color"), orientation=Qt.Horizontal, contentsLength=13,
+            searchable=True
+        )
+        self.cb_color_var.activated.connect(self.__color_var_changed)
+
+        gui.rubber(self.buttonsArea)
+        gui.auto_send(self.buttonsArea, self, "auto_commit")
+
+        self.info.set_input_summary(self.info.NoInput)
+        self.info.set_output_summary(self.info.NoOutput)
 
     @staticmethod
     def sizeHint():
