@@ -1,7 +1,6 @@
 import os
 import logging
 from itertools import chain
-from warnings import catch_warnings
 from urllib.parse import urlparse
 from typing import List
 
@@ -13,6 +12,7 @@ from AnyQt.QtCore import Qt, QTimer, QSize
 
 from Orange.data.table import Table, get_sample_datasets_dir
 from Orange.data.io import FileFormat, UrlReader, class_from_qualified_name
+from Orange.util import log_warnings
 from Orange.widgets import widget, gui
 from Orange.widgets.settings import Setting, ContextSetting, \
     PerfectDomainContextHandler, SettingProvider
@@ -91,6 +91,7 @@ class OWFile(widget.OWWidget, RecentPathsWComboMixin):
                       )
 
     want_main_area = False
+    buttons_area_orientation = None
 
     SEARCH_PATHS = [("sample-datasets", get_sample_datasets_dir())]
     SIZE_LIMIT = 1e7
@@ -126,9 +127,9 @@ class OWFile(widget.OWWidget, RecentPathsWComboMixin):
     class Warning(widget.OWWidget.Warning):
         file_too_big = Msg(__("msg.reload_file"))
         load_warning = Msg(__("msg.read_warning"))
-        performance_warning = Msg(
-            __("msg.decrease_performance"))
+        performance_warning = Msg(__("msg.decrease_performance"))
         renamed_vars = Msg(__("msg.var_renamed_avoid_duplicate"))
+        multiple_targets = Msg(__("msg.msg_multiple_targets"))
 
     class Error(widget.OWWidget.Error):
         file_not_found = Msg(__("msg.file_not_found"))
@@ -156,8 +157,9 @@ class OWFile(widget.OWWidget, RecentPathsWComboMixin):
         self.reader = None
 
         layout = QGridLayout()
-        gui.widgetBox(self.controlArea, margin=0, orientation=layout)
-        vbox = gui.radioButtons(None, self, "source", box=True, addSpace=True,
+        layout.setSpacing(4)
+        gui.widgetBox(self.controlArea, orientation=layout, box=__("box_source"))
+        vbox = gui.radioButtons(None, self, "source", box=True,
                                 callback=self.load_data, addToLayout=False)
 
         rb_button = gui.appendRadioButton(vbox, __("btn.file"), addToLayout=False)
@@ -213,7 +215,7 @@ class OWFile(widget.OWWidget, RecentPathsWComboMixin):
         url_edit = url_combo.lineEdit()
         l, t, r, b = url_edit.getTextMargins()
         url_edit.setTextMargins(l + 5, t, r, b)
-        layout.addWidget(url_combo, 3, 1, 3, 3)
+        layout.addWidget(url_combo, 3, 1, 1, 3)
         url_combo.activated.connect(self._url_set)
         # whit completer we set that combo box is case sensitive when
         # matching the history
@@ -230,14 +232,12 @@ class OWFile(widget.OWWidget, RecentPathsWComboMixin):
         self.editor_model = self.domain_editor.model()
         box.layout().addWidget(self.domain_editor)
 
-        box = gui.hBox(self.controlArea)
+        box = gui.hBox(box)
         gui.button(
-            box, self, __("btn.browse_document_data"),
-            callback=lambda: self.browse_file(True), autoDefault=False)
+            box, self, i18n.t("common.btn.reset"), callback=self.reset_domain_edit,
+            autoDefault=False
+        )
         gui.rubber(box)
-
-        gui.button(
-            box, self, i18n.t("common.btn.reset"), callback=self.reset_domain_edit)
         self.apply_button = gui.button(
             box, self, i18n.t("common.btn.apply"), callback=self.apply_domain_edit)
         self.apply_button.setEnabled(False)
@@ -245,6 +245,13 @@ class OWFile(widget.OWWidget, RecentPathsWComboMixin):
         self.editor_model.dataChanged.connect(
             lambda: self.apply_button.setEnabled(True))
 
+        hBox = gui.hBox(self.controlArea)
+        gui.rubber(hBox)
+        gui.button(
+            hBox, self, __("btn.browse_document_data"),
+            callback=lambda: self.browse_file(True), autoDefault=False)
+        gui.rubber(hBox)
+
         self.info.set_output_summary(self.info.NoOutput)
 
         self.set_file_list()
@@ -355,7 +362,7 @@ class OWFile(widget.OWWidget, RecentPathsWComboMixin):
         except Exception:
             return self.Error.sheet_error
 
-        with catch_warnings(record=True) as warnings:
+        with log_warnings() as warnings:
             try:
                 data = self.reader.read()
             except Exception as ex:
@@ -406,14 +413,12 @@ class OWFile(widget.OWWidget, RecentPathsWComboMixin):
         self.sheet_box.show()
 
     def _select_active_sheet(self):
-        if self.reader.sheet:
-            try:
-                idx = self.reader.sheets.index(self.reader.sheet)
-                self.sheet_combo.setCurrentIndex(idx)
-            except ValueError:
-                # Requested sheet does not exist in this file
-                self.reader.select_sheet(None)
-        else:
+        try:
+            idx = self.reader.sheets.index(self.reader.sheet)
+            self.sheet_combo.setCurrentIndex(idx)
+        except ValueError:
+            # Requested sheet does not exist in this file
+            self.reader.select_sheet(None)
             self.sheet_combo.setCurrentIndex(0)
 
     @staticmethod
@@ -497,6 +502,8 @@ class OWFile(widget.OWWidget, RecentPathsWComboMixin):
             if renamed:
                 self.Warning.renamed_vars(__("msg.rename").format(', '.join(renamed)))
 
+        self.Warning.multiple_targets(
+            shown=table is not None and len(table.domain.class_vars) > 1)
         summary = len(table) if table else self.info.NoOutput
         details = format_summary_details(table) if table else ""
         self.info.set_output_summary(summary, details)
