@@ -180,12 +180,9 @@ class OWImpute(OWWidget):
         self.executor = qconcurrent.ThreadExecutor(self)
         self.__task = None
 
-        main_layout = QVBoxLayout()
-        main_layout.setContentsMargins(10, 10, 10, 10)
-        self.controlArea.layout().addLayout(main_layout)
+        main_layout = self.controlArea.layout()
 
-        box = gui.vBox(None, __("box_default_method"))
-        main_layout.addWidget(box)
+        box = gui.vBox(self.controlArea, __("box_default_method"))
 
         box_layout = QGridLayout()
         box_layout.setSpacing(8)
@@ -210,7 +207,7 @@ class OWImpute(OWWidget):
 
         hlayout = QHBoxLayout()
         box.layout().addLayout(hlayout)
-        button = QRadioButton("Fixed values; numeric variables:")
+        button = QRadioButton(__("btn_default_method_index"))
         button_group.addButton(button, Method.Default)
         button.setChecked(Method.Default == self.default_method_index)
         hlayout.addWidget(button)
@@ -229,7 +226,7 @@ class OWImpute(OWWidget):
         )
         hlayout.addWidget(self.numeric_value_widget)
 
-        hlayout.addWidget(QLabel(", time:"))
+        hlayout.addWidget(QLabel(__("btn_time")))
 
         self.time_widget = gui.DateTimeEditWCalendarTime(self)
         self.time_widget.setEnabled(self.default_method_index == Method.Default)
@@ -249,12 +246,8 @@ class OWImpute(OWWidget):
 
         self.default_button_group = button_group
 
-        box = QGroupBox(title=self.tr(__("box_individual_attr")),
-                        flat=False)
-        main_layout.addWidget(box)
-
-        horizontal_layout = QHBoxLayout(box)
-        main_layout.addWidget(box)
+        box = gui.hBox(self.controlArea, self.tr(__("box_individual_attr")),
+                       flat=False)
 
         self.varview = ListViewSearch(
             selectionMode=QListView.ExtendedSelection,
@@ -268,7 +261,7 @@ class OWImpute(OWWidget):
         )
         self.selection = self.varview.selectionModel()
 
-        horizontal_layout.addWidget(self.varview)
+        box.layout().addWidget(self.varview)
         vertical_layout = QVBoxLayout(margin=0)
 
         self.methods_container = QWidget(enabled=False)
@@ -309,13 +302,11 @@ class OWImpute(OWWidget):
         vertical_layout.addStretch(2)
         vertical_layout.addWidget(self.reset_button)
 
-        horizontal_layout.addLayout(vertical_layout)
+        box.layout().addLayout(vertical_layout)
 
         self.variable_button_group = button_group
 
-        box = gui.auto_apply(self.controlArea, self, "autocommit")
-        box.button.setFixedWidth(180)
-        box.layout().insertStretch(0)
+        gui.auto_apply(self.buttonsArea, self, "autocommit")
 
         self.info.set_input_summary(self.info.NoInput)
         self.info.set_output_summary(self.info.NoOutput)
