@@ -783,25 +783,31 @@ class OWPivot(OWWidget):
         self._add_main_area_controls()
 
     def _add_control_area_controls(self):
-        box = gui.vBox(self.controlArea, box=True)
-        gui.comboBox(box, self, "row_feature", label=i18n.t("common.general.row"), contentsLength=12,
+        gui.comboBox(gui.vBox(self.controlArea, box=i18n.t("common.general.row")),
+                     self, "row_feature",
+                     contentsLength=14,
                      searchable=True,
                      model=DomainModel(valid_types=DomainModel.PRIMITIVE),
-                     callback=self.__feature_changed)
-        gui.comboBox(box, self, "col_feature", label=i18n.t("common.general.column"),
-                     contentsLength=12,
+                     callback=self.__feature_changed,
+                     orientation=Qt.Horizontal)
+        gui.comboBox(gui.vBox(self.controlArea, box=i18n.t("common.general.column")),
+                     self, "col_feature",
+                     contentsLength=14,
                      searchable=True,
                      model=DomainModel(placeholder=__("placeholder_same_as_row"),
                                        valid_types=DiscreteVariable),
-                     callback=self.__feature_changed, )
-        gui.comboBox(box, self, "val_feature", label=__("box.value"),
-                     contentsLength=12,
+                     callback=self.__feature_changed,
+                     orientation=Qt.Horizontal)
+        gui.comboBox(gui.vBox(self.controlArea, box=__("box.value")),
+                     self, "val_feature",
+                     contentsLength=14,
                      searchable=True,
                      model=DomainModel(placeholder=i18n.t("common.software.brackets_none")),
-                     callback=self.__val_feature_changed)
+                     callback=self.__val_feature_changed,
+                     orientation=Qt.Horizontal)
         self.__add_aggregation_controls()
         gui.rubber(self.controlArea)
-        gui.auto_apply(self.controlArea, self, "auto_commit")
+        gui.auto_apply(self.buttonsArea, self, "auto_commit")
 
         self.set_input_summary()
         self.set_output_summary(None, None, None)
@@ -823,7 +829,6 @@ class OWPivot(OWWidget):
         self.aggregation_checkboxes = []  # for test purposes
         for agg in self.AGGREGATIONS:
             if agg is None:
-                gui.separator(box, height=1)
                 line = QFrame()
                 line.setFrameShape(QFrame.HLine)
                 line.setLineWidth(1)
@@ -922,6 +927,13 @@ class OWPivot(OWWidget):
 
     def commit(self):
         def send_outputs(pivot_table, filtered_data, grouped_data):
+            if self.data:
+                if grouped_data:
+                    grouped_data.name = self.data.name
+                if pivot_table:
+                    pivot_table.name = self.data.name
+                if filtered_data:
+                    filtered_data.name = self.data.name
             self.Outputs.grouped_data.send(grouped_data)
             self.Outputs.pivot_table.send(pivot_table)
             self.Outputs.filtered_data.send(filtered_data)
