@@ -1117,8 +1117,24 @@ class OWPreprocess(widget.OWWidget, openclass=True):
         self.preprocessors.mimeData = mimeData
 
         box = gui.vBox(self.controlArea, __("box_preprocessor"))
+        gui.rubber(self.controlArea)
 
-        self.preprocessorsView = view = QListView(
+        # we define a class that lets us set the vertical sizeHint
+        # based on the height and number of items in the list
+        # see self.__update_list_sizeHint
+
+        class ListView(QListView):
+            def __init__(self, *args, **kwargs):
+                super().__init__(*args, **kwargs)
+                self.vertical_hint = None
+
+            def sizeHint(self):
+                sh = super().sizeHint()
+                if self.vertical_hint:
+                    return QSize(sh.width(), self.vertical_hint)
+                return sh
+
+        self.preprocessorsView = view = ListView(
             selectionMode=QListView.SingleSelection,
             dragEnabled=True,
             dragDropMode=QListView.DragOnly
@@ -1154,8 +1170,7 @@ class OWPreprocess(widget.OWWidget, openclass=True):
         self.mainArea.layout().addWidget(self.scroll_area)
         self.flow_view.installEventFilter(self)
 
-        box = gui.vBox(self.controlArea, i18n.t("common.software.output"))
-        gui.auto_apply(box, self, "autocommit", box=False)
+        gui.auto_apply(self.buttonsArea, self, "autocommit")
 
         self.info.set_input_summary(self.info.NoInput)
         self.info.set_output_summary(self.info.NoOutput)
@@ -1176,6 +1191,8 @@ class OWPreprocess(widget.OWWidget, openclass=True):
                           Qt.ItemIsDragEnabled)
             self.preprocessors.appendRow([item])
 
+        self.__update_list_sizeHint()
+
         model = self.load(self.storedsettings)
 
         self.set_model(model)
@@ -1188,6 +1205,14 @@ class OWPreprocess(widget.OWWidget, openclass=True):
 
         self.apply()
 
+    def __update_list_sizeHint(self):
+        view = self.preprocessorsView
+
+        h = view.sizeHintForRow(0)
+        n = self.preprocessors.rowCount()
+        view.vertical_hint = n * h + 2  # only on Mac?
+        view.updateGeometry()
+
     def load(self, saved):
         """Load a preprocessor list from a dict."""
         preprocessors = saved.get("preprocessors", [])
@@ -1392,10 +1417,6 @@ class OWPreprocess(widget.OWWidget, openclass=True):
             min(max(sh.width() + scroll_width + 2, self.controlArea.width()),
                 520))
 
-    def sizeHint(self):
-        sh = super().sizeHint()
-        return sh.expandedTo(QSize(sh.width() + 300, 500))
-
     def send_report(self):
         pp = [(self.controler.model().index(i, 0).data(Qt.DisplayRole), w)
               for i, w in enumerate(self.controler.view.widgets())]
