@@ -531,7 +531,7 @@ class OWPythonScript(OWWidget):
 
         self.controlBox.layout().addWidget(w)
 
-        self.execute_button = gui.button(self.controlArea, self, __('btn.run'), callback=self.commit)
+        self.execute_button = gui.button(self.buttonsArea, self, __('btn.run'), callback=self.commit)
 
         run = QAction(__("btn.run_script"), self, triggered=self.commit,
                       shortcut=QKeySequence(Qt.ControlModifier | Qt.Key_R))
@@ -543,8 +543,7 @@ class OWPythonScript(OWWidget):
         self.defaultFont = defaultFont = \
             "Monaco" if sys.platform == "darwin" else "Courier"
 
-        self.textBox = gui.vBox(self, __('box.python_script'))
-        self.splitCanvas.addWidget(self.textBox)
+        self.textBox = gui.vBox(self.splitCanvas, __('box.python_script'))
         self.text = PythonScriptEditor(self)
         self.textBox.layout().addWidget(self.text)
 
@@ -559,8 +558,7 @@ class OWPythonScript(OWWidget):
         action.setShortcutContext(Qt.WidgetWithChildrenShortcut)
         action.triggered.connect(self.saveScript)
 
-        self.consoleBox = gui.vBox(self, __('box.console'))
-        self.splitCanvas.addWidget(self.consoleBox)
+        self.consoleBox = gui.vBox(self.splitCanvas, __('box.console'))
         self.console = PythonConsole({}, self)
         self.consoleBox.layout().addWidget(self.console)
         self.console.document().setDefaultFont(QFont(defaultFont))
