@@ -180,8 +180,6 @@ class OWDataTable(OWWidget):
     priority = 50
     keywords = []
 
-    buttons_area_orientation = Qt.Vertical
-
     class Inputs:
         data = Input("Data", Table, multiple=True, label=i18n.t("widget.data.data.common.data"))
 
@@ -189,6 +187,8 @@ class OWDataTable(OWWidget):
         selected_data = Output("Selected Data", Table, default=True, label=i18n.t("widget.data.data.common.selected_data"))
         annotated_data = Output(ANNOTATED_DATA_SIGNAL_NAME, Table, label=i18n.t("widget.data.data.common.data"))
 
+    buttons_area_orientation = Qt.Vertical
+
     show_distributions = Setting(False)
     dist_color_RGB = Setting((220, 220, 220, 255))
     show_attribute_labels = Setting(True)
@@ -199,6 +199,8 @@ class OWDataTable(OWWidget):
     selected_rows = Setting([], schema_only=True)
     selected_cols = Setting([], schema_only=True)
 
+    settings_version = 2
+
     def __init__(self):
         super().__init__()
 
@@ -215,7 +217,6 @@ class OWDataTable(OWWidget):
         self.info_text = gui.widgetLabel(info_box)
         self._set_input_summary(None)
         self._set_output_summary(None)
-        gui.separator(self.controlArea)
 
         box = gui.vBox(self.controlArea, i18n.t("common.general.variable"))
         self.c_show_attribute_labels = gui.checkBox(
@@ -236,10 +237,11 @@ class OWDataTable(OWWidget):
 
         gui.rubber(self.controlArea)
 
-        reset = gui.button(
-            None, self, __("btn_restore_original"), callback=self.restore_order,
-            tooltip=__("tooltip_show_row_in_order"), autoDefault=False)
-        self.buttonsArea.layout().insertWidget(0, reset)
+        gui.button(self.buttonsArea, self, __("btn_restore_original"),
+                   callback=self.restore_order,
+                   tooltip=__("tooltip_show_row_in_order"),
+                   autoDefault=False,
+                   attribute=Qt.WA_LayoutUsesWidgetRect)
         gui.auto_send(self.buttonsArea, self, "auto_commit")
 
         # GUI with tabs
@@ -552,7 +554,7 @@ class OWDataTable(OWWidget):
     def _on_select_all(self, _):
         data_info = self.tabs.currentWidget().input_slot.summary
         if len(self.selected_rows) == data_info.len \
-                and len(self.selected_cols) == len(data_info.domain):
+                and len(self.selected_cols) == len(data_info.domain.variables):
             self.tabs.currentWidget().clearSelection()
         else:
             self.tabs.currentWidget().selectAll()
@@ -722,7 +724,7 @@ class OWDataTable(OWWidget):
 
             domain = table.domain
 
-            if len(colsel) < len(domain) + len(domain.metas):
+            if len(colsel) < len(domain.variables) + len(domain.metas):
                 # only a subset of the columns is selected
                 allvars = domain.class_vars + domain.metas + domain.attributes
                 columns = [(c, model.headerData(c, Qt.Horizontal,
@@ -742,9 +744,9 @@ class OWDataTable(OWWidget):
                 metas = select_vars(TableModel.Meta)
                 domain = Orange.data.Domain(attrs, class_vars, metas)
 
-            # Avoid a copy if none rows are selected.
+            # Send all data by default
             if not rowsel:
-                selected_data = None
+                selected_data = table
             else:
                 selected_data = table.from_table(domain, table, rowsel)
 
