@@ -122,8 +122,12 @@ time_same = VarDataPair(
     TimeVariable('time_same', have_date=True, have_time=True),
     np.array(_to_timestamps([2004] * 5), dtype=float),
 )
+time_negative = VarDataPair(
+    TimeVariable('time_negative', have_date=True, have_time=True),
+    np.array([0, -1, 24 * 60 * 60], dtype=float),
+)
 time = [
-    time_full, time_missing, time_all_missing, time_same
+    time_full, time_missing, time_all_missing, time_same, time_negative
 ]
 
 # String variable variations
@@ -249,6 +253,12 @@ class TestVariousDataSets(WidgetTest):
         self.send_signal(self.widget.Inputs.data, prepare_table(data))
         self.run_through_variables()
 
+    @table_dense_sparse
+    def test_on_data_with_negative_timestamps(self, prepare_table):
+        data = make_table([time_negative])
+        self.send_signal(self.widget.Inputs.data, prepare_table(data))
+        self.run_through_variables()
+
     def test_switching_to_dataset_with_no_target_var(self):
         """Switching from data set with target variable to a data set with
         no target variable should not result in crash."""
