@@ -4,6 +4,8 @@ from unittest.mock import Mock
 
 import numpy as np
 
+from orangewidget.widget import StateInfo
+
 from Orange.data import Table, Domain, ContinuousVariable
 from Orange.widgets.data.owneighbors import OWNeighbors, METRICS
 from Orange.widgets.tests.base import WidgetTest, ParameterMapping
@@ -126,7 +128,7 @@ class TestOWNeighbors(WidgetTest):
         summary, details = "150, 0", format_multiple_summaries(data_list)
         self.assertEqual(info._StateInfo__input_summary.brief, summary)
         self.assertEqual(info._StateInfo__input_summary.details, details)
-        self.assertEqual(info._StateInfo__output_summary.brief, "-")
+        self.assertIsInstance(info._StateInfo__output_summary, StateInfo.Empty)
         self.assertEqual(info._StateInfo__output_summary.details, no_output)
 
         self.send_signal(self.widget.Inputs.reference, reference)
@@ -144,13 +146,13 @@ class TestOWNeighbors(WidgetTest):
         summary, details = "0, 5", format_multiple_summaries(data_list)
         self.assertEqual(info._StateInfo__input_summary.brief, summary)
         self.assertEqual(info._StateInfo__input_summary.details, details)
-        self.assertEqual(info._StateInfo__output_summary.brief, "-")
+        self.assertIsInstance(info._StateInfo__output_summary, StateInfo.Empty)
         self.assertEqual(info._StateInfo__output_summary.details, no_output)
 
         self.send_signal(self.widget.Inputs.reference, None)
-        self.assertEqual(info._StateInfo__input_summary.brief, "-")
+        self.assertIsInstance(info._StateInfo__input_summary, StateInfo.Empty)
         self.assertEqual(info._StateInfo__input_summary.details, no_input)
-        self.assertEqual(info._StateInfo__output_summary.brief, "-")
+        self.assertIsInstance(info._StateInfo__output_summary, StateInfo.Empty)
         self.assertEqual(info._StateInfo__output_summary.details, no_output)
 
     def test_compute_distances_apply_called(self):
@@ -337,9 +339,9 @@ class TestOWNeighbors(WidgetTest):
 
         domain = Domain([ContinuousVariable("a")])
         domain_ref = Domain([ContinuousVariable("b")])
-        data = Table(domain, np.random.rand(2, len(domain)))
+        data = Table(domain, np.random.rand(2, len(domain.variables)))
         reference = Table(
-            domain_ref, np.random.rand(1, len(domain_ref)))
+            domain_ref, np.random.rand(1, len(domain_ref.variables)))
 
         # no error if one or both of the signals is missing
         self.send_signal(w.Inputs.data, data)
@@ -363,7 +365,7 @@ class TestOWNeighbors(WidgetTest):
 
         # different number of attributes
         domain_ref = Domain([ContinuousVariable("a"), ContinuousVariable("b")])
-        reference = Table(domain_ref, np.random.rand(1, len(domain_ref)))
+        reference = Table(domain_ref, np.random.rand(1, len(domain_ref.variables)))
 
         # error disappears when data is set to None
         self.send_signal(w.Inputs.data, data)
