@@ -54,6 +54,8 @@ class OWPredictions(OWWidget):
     description = __("desc")
     keywords = []
 
+    buttons_area_orientation = None
+
     class Inputs:
         data = Input("Data", Orange.data.Table, label=i18n.t("widget.evaluate.evaluate.common.data"))
         predictors = Input("Predictors", Model, multiple=True, label=i18n.t("widget.evaluate.evaluate.common.predictor"))
@@ -92,15 +94,16 @@ class OWPredictions(OWWidget):
         self._set_input_summary()
         self._set_output_summary(None)
 
-        gui.listBox(self.controlArea, self, "selected_classes", "class_values",
-                    box=__("box_show_probability"),
+        controlBox = gui.vBox(self.controlArea, __("box_show_probability"))
+
+        gui.listBox(controlBox, self, "selected_classes", "class_values",
                     callback=self._update_prediction_delegate,
                     selectionMode=QListWidget.ExtendedSelection,
-                    addSpace=False,
-                    sizePolicy=(QSizePolicy.Preferred, QSizePolicy.Preferred))
-        gui.rubber(self.controlArea)
+                    sizePolicy=(QSizePolicy.Preferred, QSizePolicy.MinimumExpanding),
+                    sizeHint=QSize(1, 350),
+                    minimumHeight=100)
         self.reset_button = gui.button(
-            self.controlArea, self, __("btn_restore_original"),
+            controlBox, self, __("btn_restore_original"),
             callback=self._reset_order,
             tooltip=__("tooltip_original_row"))
 
