@@ -14,6 +14,7 @@ from AnyQt.QtWidgets import (
     QComboBox, QSpinBox, QDoubleSpinBox, QSlider
 )
 
+from orangewidget.widget import StateInfo
 from orangewidget.tests.base import (
     GuiTest, WidgetTest as WidgetTestBase, DummySignalManager, DEFAULT_TIMEOUT
 )
@@ -499,10 +500,11 @@ class WidgetOutputsTestMixin:
     _compare_selected_annotated_domains.
     """
 
-    def init(self, same_table_attributes=True):
+    def init(self, same_table_attributes=True, output_all_on_no_selection=False):
         self.data = Table("iris")
         self.same_input_output_domain = True
         self.same_table_attributes = same_table_attributes
+        self.output_all_on_no_selection = output_all_on_no_selection
 
     def test_outputs(self, timeout=DEFAULT_TIMEOUT):
         self.send_signal(self.signal_name, self.signal_data)
@@ -510,7 +512,11 @@ class WidgetOutputsTestMixin:
         self.wait_until_finished(timeout=timeout)
 
         # check selected data output
-        self.assertIsNone(self.get_output("Selected Data"))
+        output = self.get_output("Selected Data")
+        if self.output_all_on_no_selection:
+            self.assertEqual(output, self.signal_data)
+        else:
+            self.assertIsNone(output)
 
         # check annotated data output
         feature_name = ANNOTATED_DATA_FEATURE_NAME
@@ -758,8 +764,8 @@ class ProjectionWidgetTestMixin:
 
     def test_in_out_summary(self, timeout=DEFAULT_TIMEOUT):
         info = self.widget.info
-        self.assertEqual(info._StateInfo__input_summary.brief, "-")
-        self.assertEqual(info._StateInfo__output_summary.brief, "-")
+        self.assertIsInstance(info._StateInfo__input_summary, StateInfo.Empty)
+        self.assertIsInstance(info._StateInfo__output_summary, StateInfo.Empty)
         self.assertIn(info._StateInfo__input_summary.details,
                       ["", "No data on input"])
         self.assertIn(info._StateInfo__output_summary.details,
@@ -782,8 +788,8 @@ class ProjectionWidgetTestMixin:
                          ["", "No data on output"])
 
         self.send_signal(self.widget.Inputs.data, None)
-        self.assertEqual(info._StateInfo__input_summary.brief, "-")
-        self.assertEqual(info._StateInfo__output_summary.brief, "-")
+        self.assertIsInstance(info._StateInfo__input_summary, StateInfo.Empty)
+        self.assertIsInstance(info._StateInfo__output_summary, StateInfo.Empty)
         self.assertIn(info._StateInfo__input_summary.details,
                       ["", "No data on input"])
         self.assertIn(info._StateInfo__output_summary.details,
