@@ -2,6 +2,8 @@ from concurrent.futures import Future
 from typing import Optional, List, Dict
 
 import numpy as np
+import scipy.sparse as sp
+
 from AnyQt.QtCore import Qt, QTimer, QAbstractTableModel, QModelIndex, QThread, \
     pyqtSlot as Slot
 from AnyQt.QtGui import QIntValidator
@@ -134,12 +136,12 @@ class OWKMeans(widget.OWWidget):
         not_enough_data = widget.Msg(
             __("msg.unique_data_little")
         )
+        no_sparse_normalization = widget.Msg("Sparse data cannot be normalized")
 
     INIT_METHODS = (("Initialize with KMeans++", "k-means++"),
                     ("Random initialization", "random"))
 
     resizing_enabled = False
-    buttons_area_orientation = Qt.Vertical
 
     k = Setting(3)
     k_from = Setting(2)
@@ -231,12 +233,13 @@ class OWKMeans(widget.OWWidget):
             sb, self, "max_iterations", controlWidth=60, valueType=int,
             validator=QIntValidator(), callback=self.invalidate)
 
-        self.apply_button = gui.auto_apply(self.buttonsArea, self, "auto_commit", box=None,
-                                           commit=self.commit)
-        gui.rubber(self.controlArea)
-
         box = gui.vBox(self.mainArea, box=__("box.silhouette_scores"))
-        self.mainArea.setVisible(self.optimize_k)
+        if self.optimize_k:
+            self.mainArea.setVisible(True)
+            self.left_side.setContentsMargins(0, 0, 0, 0)
+        else:
+            self.mainArea.setVisible(False)
+            self.left_side.setContentsMargins(0, 0, 4, 0)
         self.table_model = ClusterTableModel(self)
         table = self.table_view = QTableView(self.mainArea)
         table.setModel(self.table_model)
@@ -250,6 +253,9 @@ class OWKMeans(widget.OWWidget):
         table.setShowGrid(False)
         box.layout().addWidget(table)
 
+        self.apply_button = gui.auto_apply(self.buttonsArea, self, "auto_commit",
+                                           commit=self.commit)
+
     def adjustSize(self):
         self.ensurePolished()
         s = self.sizeHint()
@@ -432,8 +438,12 @@ class OWKMeans(widget.OWWidget):
         # cause flickering when the clusters are computed quickly, so this is
         # the better alternative
         self.table_model.clear_scores()
-        self.mainArea.setVisible(self.optimize_k and self.data is not None and
-                                 self.has_attributes)
+        if self.optimize_k and self.data is not None and self.has_attributes:
+            self.mainArea.setVisible(True)
+            self.left_side.setContentsMargins(0, 0, 0, 0)
+        else:
+            self.mainArea.setVisible(False)
+            self.left_side.setContentsMargins(0, 0, 4, 0)
 
         if self.data is None:
             self.send_data()
@@ -494,7 +504,10 @@ class OWKMeans(widget.OWWidget):
 
     def preproces(self, data):
         if self.normalize:
-            data = Normalize()(data)
+            if sp.issparse(data.X):
+                self.Warning.no_sparse_normalization()
+            else:
+                data = Normalize()(data)
         for preprocessor in KMeans.preprocessors:  # use same preprocessors than
             data = preprocessor(data)
         return data
@@ -574,6 +587,9 @@ class OWKMeans(widget.OWWidget):
         self.selection = None
         self._set_input_summary()
 
+        self.controls.normalize.setDisabled(
+            bool(self.data) and sp.issparse(self.data.X))
+
         # Do not needlessly recluster the data if X hasn't changed
         if old_data and self.data and array_equal(self.data.X, old_data.X):
             if self.auto_commit:
