@@ -113,11 +113,11 @@ class OWLouvainClustering(widget.OWWidget):
         preprocessing_box = gui.vBox(self.controlArea, __("box_preprocessing"))
         self.normalize_cbx = gui.checkBox(
             preprocessing_box, self, "normalize", label=__("checkbox_normalize_data"),
-            callback=self._invalidate_preprocessed_data,
+            callback=self._invalidate_preprocessed_data, attribute=Qt.WA_LayoutUsesWidgetRect
         )  # type: QCheckBox
         self.apply_pca_cbx = gui.checkBox(
             preprocessing_box, self, "apply_pca", label=__("checkbox_apply"),
-            callback=self._apply_pca_changed,
+            callback=self._apply_pca_changed, attribute=Qt.WA_LayoutUsesWidgetRect
         )  # type: QCheckBox
         self.pca_components_slider = gui.hSlider(
             preprocessing_box, self, "pca_components", label=__("row_PCA_components"), minValue=2,
@@ -145,7 +145,7 @@ class OWLouvainClustering(widget.OWWidget):
             __("row_resolution_tip")
         )
         self.apply_button = gui.auto_apply(
-            self.controlArea, self, "auto_commit", box=None,
+            self.buttonsArea, self, "auto_commit",
             commit=lambda: self.commit(), callback=lambda: self._on_auto_commit_changed()
         )  # type: QWidget
 
