@@ -231,16 +231,16 @@ class OWMDS(OWDataProjectionWidget, ConcurrentWidgetMixin):
         )
 
     def _add_controls_optimization(self):
-        box = gui.vBox(self.controlArea, box=True)
-        self.run_button = gui.button(box, self, __("btn.start"), self._toggle_run)
+        box = gui.vBox(self.controlArea, box="Optimize", spacing=0)
+        hbox = gui.hBox(box, margin=0)
+        gui.button(hbox, self, i18n.t("common.algorithm.PCA"), callback=self.do_PCA, autoDefault=False)
+        gui.button(hbox, self, i18n.t("common.general.randomize"), callback=self.do_random, autoDefault=False)
+        gui.button(hbox, self, __("btn.jitter"), callback=self.do_jitter, autoDefault=False)
         gui.comboBox(box, self, "refresh_rate", label=__("row_refresh"),
                      orientation=Qt.Horizontal,
                      items=[t for t, _ in OWMDS.RefreshRate],
                      callback=self.__refresh_rate_combo_changed)
-        hbox = gui.hBox(box, margin=0)
-        gui.button(hbox, self, i18n.t("common.algorithm.PCA"), callback=self.do_PCA)
-        gui.button(hbox, self, i18n.t("common.general.randomize"), callback=self.do_random)
-        gui.button(hbox, self, __("btn.jitter"), callback=self.do_jitter)
+        self.run_button = gui.button(box, self, __("btn.start"), self._toggle_run)
 
     def __refresh_rate_combo_changed(self):
         if self.task is not None:
