@@ -335,6 +335,10 @@ class OWDistributions(OWWidget):
             callback=self._on_sort_by_freq, stateWhenDisabled=False)
 
         box = self.continuous_box = gui.vBox(self.controlArea, i18n.t("common.general.distribution"))
+        gui.comboBox(
+            box, self, "fitted_distribution", label=__("label.fitted_distribution"),
+            orientation=Qt.Horizontal, items=(name[0] for name in self.Fitters),
+            callback=self._on_fitted_dist_changed)
         slider = gui.hSlider(
             box, self, "number_of_bins",
             label=__("row_bin_width"), orientation=Qt.Horizontal,
@@ -344,15 +348,10 @@ class OWDistributions(OWWidget):
         self.bin_width_label.setFixedWidth(35)
         self.bin_width_label.setAlignment(Qt.AlignRight)
         slider.sliderReleased.connect(self._on_bin_slider_released)
-        gui.comboBox(
-            box, self, "fitted_distribution", label=__("label.fitted_distribution"),
-            orientation=Qt.Horizontal, items=(name[0] for name in self.Fitters),
-            callback=self._on_fitted_dist_changed)
-        self.smoothing_box = gui.indentedBox(box, 40)
-        gui.hSlider(
-            self.smoothing_box, self, "kde_smoothing",
+        self.smoothing_box = gui.hSlider(
+            box, self, "kde_smoothing",
             label=__("label.smoothing"), orientation=Qt.Horizontal,
-            minValue=2, maxValue=20, callback=self.replot)
+            minValue=2, maxValue=20, callback=self.replot, disabled=True)
         gui.checkBox(
             box, self, "hide_bars", __("checkbox.hide_bars"), stateWhenDisabled=False,
             callback=self._on_hide_bars_changed,
@@ -375,7 +374,7 @@ class OWDistributions(OWWidget):
             box, self, "cumulative_distr", __("checkbox.cumulative_distribution"),
             callback=self._on_show_cumulative)
 
-        gui.auto_apply(self.controlArea, self, commit=self.apply)
+        gui.auto_apply(self.buttonsArea, self, commit=self.apply)
 
         self.info.set_input_summary(self.info.NoInput)
         self.info.set_output_summary(self.info.NoOutput)
@@ -398,7 +397,8 @@ class OWDistributions(OWWidget):
         self.plotview.blank_clicked.connect(self._on_blank_clicked)
         self.plotview.mouse_released.connect(self._on_end_selecting)
         self.plotview.setRenderHint(QPainter.Antialiasing)
-        self.mainArea.layout().addWidget(self.plotview)
+        box = gui.vBox(self.mainArea, box=True, margin=0)
+        box.layout().addWidget(self.plotview)
         self.ploti = pg.PlotItem(
             enableMenu=False, enableMouse=False,
             axisItems={"bottom": ElidedAxisNoUnits("bottom")})
@@ -507,8 +507,8 @@ class OWDistributions(OWWidget):
         self.plot.update()
 
     def _set_smoothing_visibility(self):
-        self.smoothing_box.setVisible(
-            self.Fitters[self.fitted_distribution][1] is AshCurve)
+        self.smoothing_box.setDisabled(
+            self.Fitters[self.fitted_distribution][1] is not AshCurve)
 
     def _set_bin_width_slider_label(self):
         if self.number_of_bins < len(self.binnings):
@@ -590,10 +590,10 @@ class OWDistributions(OWWidget):
         bottomaxis.setShowUnit(not (self.var and self.var.is_time))
 
         leftaxis = self.ploti.getAxis("left")
-        if self.show_probs and self.cvar:
-            leftaxis.setLabel(__("label.get_probability").format(self.cvar.name, self.var.name))
-        else:
-            leftaxis.setLabel(__("label.frequency"))
+        # if self.show_probs and self.cvar:
+        #     leftaxis.setLabel(__("label.get_probability").format(self.cvar.name, self.var.name))
+        # else:
+        leftaxis.setLabel(__("label.frequency"))
         leftaxis.resizeEvent()
 
     def _update_controls_state(self):
