@@ -195,8 +195,6 @@ class OWHeatMap(widget.OWWidget):
 
     graph_name = "scene"
 
-    left_side_scrolling = True
-
     class Information(widget.OWWidget.Information):
         sampled = Msg(__("msg.data_sampled"))
         discrete_ignored = Msg(__("msg.ignore_categorical_feature"))
@@ -380,7 +378,8 @@ class OWHeatMap(widget.OWWidget):
 
         gui.checkBox(box, self, 'averages', __('checkbox.stripes_averages'),
                      callback=self.update_averages_stripe)
-        annotbox = QGroupBox(__("box.row_annotations"), flat=True)
+        gui.separator(box)
+        annotbox = QGroupBox(__("box.row_annotations"))
         form = QFormLayout(
             annotbox,
             formAlignment=Qt.AlignLeft,
@@ -413,7 +412,7 @@ class OWHeatMap(widget.OWWidget):
         form.addRow(i18n.t("common.software.text"), self.annotation_text_cb)
         form.addRow(__("row.color"), self.row_side_color_cb)
         box.layout().addWidget(annotbox)
-        annotbox = QGroupBox(__("box.column_labels_position"), flat=True)
+        annotbox = QGroupBox(__("box.column_labels_position"))
         form = QFormLayout(
             annotbox,
             formAlignment=Qt.AlignLeft,
@@ -442,8 +441,8 @@ class OWHeatMap(widget.OWWidget):
             callback=self.update_column_annotations)
         cb.setModel(create_list_model(ColumnLabelsPosData, parent=self))
         cb.setCurrentIndex(self.column_label_pos)
+        form.addRow(__("row.position"), cb)
         form.addRow(__("row.color"), self.col_side_color_cb)
-        form.addRow(__("row.label_position"), cb)
         box.layout().addWidget(annotbox)
 
         gui.checkBox(self.controlArea, self, "keep_aspect",
@@ -451,7 +450,8 @@ class OWHeatMap(widget.OWWidget):
                      callback=self.__aspect_mode_changed)
 
         gui.rubber(self.controlArea)
-        gui.auto_send(self.controlArea, self, "auto_commit")
+
+        gui.auto_send(self.buttonsArea, self, "auto_commit")
 
         # Scene with heatmap
         class HeatmapScene(QGraphicsScene):
