@@ -139,6 +139,9 @@ class RadvizVizRank(VizRankDialog, OWComponent):
                                          len(master.model_selected)))
         return True
 
+    def on_selection_changed(self, selected, _):
+        self.on_row_clicked(selected.indexes()[0])
+
     def on_row_clicked(self, index):
         self.selectionChanged.emit(index.data(self._AttrRole))
 
@@ -329,17 +332,20 @@ class OWRadviz(OWAnchorProjectionWidget):
         max_vars_selected = widget.Msg(__("msg.number_error"))
 
     def _add_controls(self):
+        box = gui.vBox(self.controlArea, box=i18n.t("common.general.features"))
         self.model_selected = VariableSelectionModel(self.selected_vars,
                                                      max_vars=20)
-        variables_selection(self.controlArea, self, self.model_selected)
+        variables_selection(box, self, self.model_selected)
         self.model_selected.selection_changed.connect(
             self.__model_selected_changed)
         self.vizrank, self.btn_vizrank = RadvizVizRank.add_vizrank(
             None, self, __("btn.suggest_feature"), self.vizrank_set_attrs)
-        self.controlArea.layout().addWidget(self.btn_vizrank)
+        box.layout().addWidget(self.btn_vizrank)
         super()._add_controls()
-        self.controlArea.layout().removeWidget(self.control_area_stretch)
-        self.control_area_stretch.setParent(None)
+
+    def _add_buttons(self):
+        self.gui.box_zoom_select(self.buttonsArea)
+        gui.auto_send(self.buttonsArea, self, "auto_commit")
 
     @property
     def primitive_variables(self):
