@@ -28,9 +28,12 @@ from Orange.widgets.visualize.utils import VizRankDialogAttrPair
 from Orange.widgets.visualize.utils.widget import OWDataProjectionWidget
 from Orange.widgets.widget import AttributeList, Msg, Input, Output
 from Orange.i18n_config import *
+
+
 def __(key):
     return i18n.t("widget.visualize.visualize.owscatterplot." + key)
 
+
 class ScatterPlotVizRank(VizRankDialogAttrPair):
     captionTitle = i18n.t("common.software.score_plot")
     minK = 10
@@ -281,7 +284,7 @@ class OWScatterPlot(OWDataProjectionWidget):
              self.gui.RegressionLine],
             self._plot_box)
         gui.checkBox(
-            gui.indentedBox(self._plot_box), self,
+            self._plot_box, self,
             value="graph.orthonormal_regression",
             label=__("checkbox.variable_independent"),
             callback=self.graph.update_regression_line,
@@ -291,28 +294,29 @@ class OWScatterPlot(OWDataProjectionWidget):
     def _add_controls_axis(self):
         common_options = dict(
             labelWidth=50, orientation=Qt.Horizontal, sendSelectedValue=True,
-            contentsLength=14
+            contentsLength=12, searchable=True
         )
-        self.attr_box = gui.vBox(self.controlArea, True)
+        self.attr_box = gui.vBox(self.controlArea, __("box.axes"),
+                                 spacing=2 if gui.is_macstyle() else 8)
         dmod = DomainModel
         self.xy_model = DomainModel(dmod.MIXED, valid_types=ContinuousVariable)
         self.cb_attr_x = gui.comboBox(
             self.attr_box, self, "attr_x", label=__("label.axis_x"),
             callback=self.set_attr_from_combo,
             model=self.xy_model, **common_options,
-            searchable=True)
+        )
         self.cb_attr_y = gui.comboBox(
             self.attr_box, self, "attr_y", label=__("label.axis_y"),
             callback=self.set_attr_from_combo,
             model=self.xy_model, **common_options,
-            searchable=True)
+        )
         vizrank_box = gui.hBox(self.attr_box)
         self.vizrank, self.vizrank_button = ScatterPlotVizRank.add_vizrank(
             vizrank_box, self, __("btn_informative_projection"), self.set_attr)
 
     def _add_controls_sampling(self):
         self.sampling = gui.auto_commit(
-            self.controlArea, self, "auto_sample", "Sample", box="Sampling",
+            self.controlArea, self, "auto_sample", "Sample", box=__("box.sample"),
             callback=self.switch_sampling, commit=lambda: self.add_data(1))
         self.sampling.setVisible(False)
 
@@ -394,7 +398,7 @@ class OWScatterPlot(OWDataProjectionWidget):
                 self.data = None
 
         if self.data is not None and (len(self.data) == 0 or
-                                      len(self.data.domain) == 0):
+                                      len(self.data.domain.variables) == 0):
             self.data = None
 
     def get_embedding(self):
