@@ -4,7 +4,6 @@ import warnings
 from xml.sax.saxutils import escape
 from math import log10, floor, ceil
 from datetime import datetime, timezone
-from time import gmtime
 
 import numpy as np
 from AnyQt.QtCore import Qt, QRectF, QSize, QTimer, pyqtSignal as Signal, \
@@ -20,11 +19,10 @@ from pyqtgraph.graphicsItems.LegendItem import LegendItem as PgLegendItem
 from pyqtgraph.graphicsItems.TextItem import TextItem
 
 from Orange.preprocess.discretize import _time_binnings
-from Orange.widgets.utils import colorpalettes
-from Orange.util import OrangeDeprecationWarning
+from Orange.util import utc_from_timestamp
 from Orange.widgets import gui
 from Orange.widgets.settings import Setting
-from Orange.widgets.utils import classdensity
+from Orange.widgets.utils import classdensity, colorpalettes
 from Orange.widgets.utils.plot import OWPalette
 from Orange.widgets.visualize.utils.customizableplot import Updater, \
     CommonParameterSetter
@@ -34,16 +32,6 @@ from Orange.widgets.visualize.utils.plotutils import (
 )
 from Orange.i18n_config import *
 
-with warnings.catch_warnings():
-    # This just loads an obsolete module; proper warning is issued below
-    warnings.simplefilter("ignore", DeprecationWarning)
-    from Orange.widgets.visualize.owscatterplotgraph_obsolete import (
-        OWScatterPlotGraph as OWScatterPlotGraphObs
-    )
-
-def __(key):
-    return i18n.t("widget.visualize.visualize.owscatterplotgraph." + key)
-
 SELECTION_WIDTH = 5
 MAX_N_VALID_SIZE_ANIMATE = 1000
 
@@ -51,6 +39,10 @@ MAX_N_VALID_SIZE_ANIMATE = 1000
 MAX_COLORS = 11
 
 
+def __(key):
+    return i18n.t("widget.visualize.visualize.owscatterplotgraph." + key)
+
+
 class LegendItem(PgLegendItem):
     def __init__(self, size=None, offset=None, pen=None, brush=None):
         super().__init__(size, offset)
@@ -177,22 +169,6 @@ class DiscretizedScale:
         return self.offset + self.width * np.arange(self.bins + 1)
 
 
-class InteractiveViewBox(ViewBox):
-    def __init__(self, graph, enable_menu=False):
-        super().__init__(graph, enable_menu)
-        warnings.warn("InteractiveViewBox class has been deprecated since "
-                      "3.17. Use Orange.widgets.visualize.utils.plotutils."
-                      "InteractiveViewBox instead.", OrangeDeprecationWarning)
-
-
-class OWScatterPlotGraph(OWScatterPlotGraphObs):
-    def __init__(self, scatter_widget, parent=None, _="None", view_box=InteractiveViewBox):
-        super().__init__(scatter_widget, parent=parent, _=_, view_box=view_box)
-        warnings.warn("OWScatterPlotGraph class has been deprecated since "
-                      "3.17. Use OWScatterPlotBase instead.",
-                      OrangeDeprecationWarning)
-
-
 class ScatterPlotItem(pg.ScatterPlotItem):
     """
     Modifies the behaviour of ScatterPlotItem as follows:
@@ -340,8 +316,8 @@ class AxisItem(AxisItem):
                      datetime.min.replace(tzinfo=timezone.utc).timestamp() + 1)
         maxVal = min(maxVal,
                      datetime.max.replace(tzinfo=timezone.utc).timestamp() - 1)
-        mn, mx = gmtime(minVal), gmtime(maxVal)
-
+        mn = utc_from_timestamp(minVal).timetuple()
+        mx = utc_from_timestamp(maxVal).timetuple()
         try:
             bins = _time_binnings(mn, mx, 6, 30)[-1]
         except (IndexError, ValueError):
@@ -379,10 +355,7 @@ class AxisItem(AxisItem):
         else:
             fmt = '%S.%f'
 
-        # if timezone is not set, then local timezone is used
-        # which cause exceptions for edge cases
-        return [datetime.fromtimestamp(x, tz=timezone.utc).strftime(fmt)
-                for x in values]
+        return [utc_from_timestamp(x).strftime(fmt) for x in values]
 
 
 class ScatterBaseParameterSetter(CommonParameterSetter):
@@ -1639,11 +1612,3 @@ class OWScatterPlotBase(gui.OWComponent, QObject):
             return True
         else:
             return False
-
-
-class HelpEventDelegate(EventDelegate):
-    def __init__(self, delegate, parent=None):
-        super().__init__(delegate, parent)
-        warnings.warn("HelpEventDelegate class has been deprecated since 3.17."
-                      " Use Orange.widgets.visualize.utils.plotutils."
-                      "HelpEventDelegate instead.", OrangeDeprecationWarning)
