@@ -16,6 +16,8 @@ from pyqtgraph.Point import Point
 
 from orangewidget.tests.base import DEFAULT_TIMEOUT
 
+from orangewidget.widget import StateInfo
+
 from Orange.data import Table
 from Orange.widgets.tests.base import (
     WidgetTest, WidgetOutputsTestMixin, datasets
@@ -158,14 +160,6 @@ class TestOWLinePLot(WidgetTest, WidgetOutputsTestMixin):
         pos_down, pos_up = QPointF(2.38, 4.84), QPointF(3.58, 4.76)
         mapToParent = self.widget.graph.view_box.childGroup.mapToParent
 
-        # On pyqtgraph < 0.11.1 mapping does not work unless the widget is shown
-        # Delete when Orange stops supporting pyqtgraph < 0.11.1,
-        to_and_back = self.widget.graph.view_box.childGroup.mapFromParent(
-            mapToParent(pos_down))
-        successful_mapping = (to_and_back - pos_down).manhattanLength() < 0.001
-        if not successful_mapping:  # on pyqtgraph < 0.11.1
-            mapToParent = lambda x: x
-
         event.buttonDownPos.return_value = mapToParent(pos_down)
         event.pos.return_value = mapToParent(pos_up)
 
@@ -178,12 +172,6 @@ class TestOWLinePLot(WidgetTest, WidgetOutputsTestMixin):
         self.widget.graph.view_box.mouseClickEvent(event)
         self.assertListEqual(self.widget.selection, [])
 
-    def test_remove_old_pyqtgraph_support(self):
-        # When 0.11.2 is released there is probably time to drop support
-        # for pyqtgraph <= 0.11.0:
-        # - remove test_selection_line workaround for 0.11.0
-        self.assertLess(pyqtgraph.__version__, "0.11.2")
-
     @patch("Orange.widgets.visualize.owlineplot.SEL_MAX_INSTANCES", 100)
     def test_select_lines_enabled(self):
         self.send_signal(self.widget.Inputs.data, self.data[::2])
@@ -244,6 +232,14 @@ class TestOWLinePLot(WidgetTest, WidgetOutputsTestMixin):
         self.assertEqual(p, 2)
         self.assertFalse(self.widget.graph.legend.isVisible())
 
+    def test_group_var_none_single_instance(self):
+        self.send_signal(self.widget.Inputs.data, self.housing[:1])
+        m, n, p = self.widget.graph.view_box._profile_items.shape
+        self.assertEqual(m, len(self.housing.domain.attributes))
+        self.assertEqual(n, 1)
+        self.assertEqual(p, 2)
+        self.assertFalse(self.widget.graph.legend.isVisible())
+
     def test_datasets(self):
         for ds in datasets.datasets():
             self.send_signal(self.widget.Inputs.data, ds)
@@ -310,7 +306,7 @@ class TestOWLinePLot(WidgetTest, WidgetOutputsTestMixin):
         summary, details = f"{len(data)}", format_summary_details(data)
         self.assertEqual(info._StateInfo__input_summary.brief, summary)
         self.assertEqual(info._StateInfo__input_summary.details, details)
-        self.assertEqual(info._StateInfo__output_summary.brief, "-")
+        self.assertIsInstance(info._StateInfo__output_summary, StateInfo.Empty)
         self.assertEqual(info._StateInfo__output_summary.details, no_output)
 
         sel_indices = list(range(5))
@@ -321,9 +317,9 @@ class TestOWLinePLot(WidgetTest, WidgetOutputsTestMixin):
         self.assertEqual(info._StateInfo__output_summary.details, details)
 
         self.send_signal(self.widget.Inputs.data, None)
-        self.assertEqual(info._StateInfo__input_summary.brief, "-")
+        self.assertIsInstance(info._StateInfo__input_summary, StateInfo.Empty)
         self.assertEqual(info._StateInfo__input_summary.details, no_input)
-        self.assertEqual(info._StateInfo__output_summary.brief, "-")
+        self.assertIsInstance(info._StateInfo__output_summary, StateInfo.Empty)
         self.assertEqual(info._StateInfo__output_summary.details, no_output)
 
     def test_visual_settings(self, timeout=DEFAULT_TIMEOUT):
